.. _smachine_module:

-----------------------
:mod:`ginsfsm.smachine`
-----------------------

.. automodule:: ginsfsm.smachine

.. autoclass:: SMachine
    :members: inject_event,
        set_new_state, get_current_state,
        get_input_event_list, get_output_event_list,
        set_trace_mach

.. autoexception:: MachineError

.. autoexception:: EventError

.. autoexception:: StateError

.. autoexception:: EventNotAcceptedError
